Index: channels/sig_pri.h
===================================================================
--- channels/sig_pri.h	(revision 261494)
+++ channels/sig_pri.h	(working copy)
@@ -311,7 +311,7 @@
 	 * AST_DEVICE_BUSY - All B channels are in use.
 	 * AST_DEVICE_UNAVAILABLE - Span is in alarm.
 	 * \note
-	 * Device name:  DAHDI/I<span>/congestion
+	 * Device name: \startverbatim DAHDI/I<span>/congestion. \endverbatim
 	 */
 	int congestion_devstate;
 #if defined(THRESHOLD_DEVSTATE_PLACEHOLDER)
Index: channels/chan_dahdi.c
===================================================================
--- channels/chan_dahdi.c	(revision 261494)
+++ channels/chan_dahdi.c	(working copy)
@@ -9102,7 +9102,7 @@
 
 /*! \brief enable or disable the chan_dahdi Do-Not-Disturb mode for a DAHDI channel
  * \param dahdichan "Physical" DAHDI channel (e.g: DAHDI/5)
- * \param on 1 to enable, 0 to disable, -1 return dnd value
+ * \param flag on 1 to enable, 0 to disable, -1 return dnd value
  *
  * chan_dahdi has a DND (Do Not Disturb) mode for each dahdichan (physical
  * DAHDI channel). Use this to enable or disable it.
Index: channels/chan_sip.c
===================================================================
--- channels/chan_sip.c	(revision 261494)
+++ channels/chan_sip.c	(working copy)
@@ -4472,7 +4472,7 @@
 
 /*!
  * \brief Locate device by name or ip address
- *
+ * \param peer, sin, realtime, devstate_only, transport
  * \param which_objects Define which objects should be matched when doing a lookup
  *        by name.  Valid options are FINDUSERS, FINDPEERS, or FINDALLDEVICES.
  *        Note that this option is not used at all when doing a lookup by IP.
@@ -10556,7 +10556,6 @@
  *
  * \param req The request/response to which we will add the header
  * \param pvt The sip_pvt which represents the call-leg
- * \param apr Redirecting data used to make the diversion header
  */
 static void add_diversion_header(struct sip_request *req, struct sip_pvt *pvt)
 {
@@ -10620,12 +10619,14 @@
 	return 0;
 }
 
-/*! \brief Build REFER/INVITE/OPTIONS/SUBSCRIBE message and transmit it
-	\param init 0 = Prepare request within dialog, 1= prepare request, new branch, 2= prepare new request and new dialog. do_proxy_auth calls this with init!=2
- \param p sip_pvt structure
- \param sdp unknown
- \param sipmethod unknown
-
+/*! 
+ * \brief Build REFER/INVITE/OPTIONS/SUBSCRIBE message and transmit it
+ * \param p sip_pvt structure
+ * \param sipmethod
+ * \param sdp unknown
+ * \param init 0 = Prepare request within dialog, 1= prepare request, new branch,
+ *  2= prepare new request and new dialog. do_proxy_auth calls this with init!=2
+ * \param explicit_uri
 */
 static int transmit_invite(struct sip_pvt *p, int sipmethod, int sdp, int init, const char * const explicit_uri)
 {
Index: apps/app_meetme.c
===================================================================
--- apps/app_meetme.c	(revision 261494)
+++ apps/app_meetme.c	(working copy)
@@ -944,11 +944,12 @@
  *  when in a conference */
 static int audio_buffers;
 
-/*!  \briefMap 'volume' levels from -5 through +5 into
- *  decibel (dB) settings for channel drivers
+/*! \brief Map 'volume' levels from -5 through +5 into decibel (dB) 
+ *    settings for channel drivers.
+ *
  *  \note these are not a straight linear-to-dB
  *  conversion... the numbers have been modified
- *  to give the user a better level of adjustability
+ *  to give the user a better level of adjustability.
  */
 static const char gain_map[] = {
 	-15,
@@ -5067,7 +5068,7 @@
 
 /*! \brief Choose the highest priority ringing trunk for a station
  * \param station the station
- * \param remove remove the ringing trunk once selected
+ * \param rm remove the ringing trunk once selected
  * \param trunk_ref a place to store the pointer to this stations reference to
  *        the selected trunk
  * \return a pointer to the selected ringing trunk, or NULL if none found
Index: apps/app_voicemail.c
===================================================================
--- apps/app_voicemail.c	(revision 261494)
+++ apps/app_voicemail.c	(working copy)
@@ -1550,6 +1550,9 @@
  * \brief Creates a file system path expression for a folder within the voicemail data folder and the appropriate context.
  * \param dest The variable to hold the output generated path expression. This buffer should be of size PATH_MAX.
  * \param len The length of the path string that was written out.
+ * \param context
+ * \param ext 
+ * \param folder 
  * 
  * The path is constructed as 
  * 	VM_SPOOL_DIRcontext/ext/folder
@@ -1565,6 +1568,8 @@
  * \brief Creates a file system path expression for a folder within the voicemail data folder and the appropriate context.
  * \param dest The variable to hold the output generated path expression. This buffer should be of size PATH_MAX.
  * \param len The length of the path string that was written out.
+ * \param dir 
+ * \param num 
  * 
  * The path is constructed as 
  * 	VM_SPOOL_DIRcontext/ext/folder
@@ -4313,15 +4318,18 @@
  * \param msgnum The message index in the mailbox folder.
  * \param context 
  * \param mailbox The voicemail box to read the voicemail to be notified in this email.
+ * \param fromfolder
  * \param cidnum The caller ID number.
  * \param cidname The caller ID name.
  * \param attach the name of the sound file to be attached to the email, if attach_user_voicemail == 1.
+ * \param attach2 
  * \param format The message sound file format. i.e. .wav
  * \param duration The time of the message content, in seconds.
  * \param attach_user_voicemail if 1, the sound file is attached to the email.
  * \param chan
  * \param category
  * \param imap if == 1, indicates the target folder for the email notification to be sent to will be an IMAP mailstore. This causes additional mailbox headers to be set, which would facilitate searching for the email in the destination IMAP folder.
+ * \param flag
  *
  * The email body, and base 64 encoded attachement (if any) are stored to the file identified by *p. This method does not actually send the email.  That is done by invoking the configure 'mailcmd' and piping this generated file into it, or with the sendemail() function.
  */
@@ -5100,6 +5108,7 @@
  * \param recip
  * \param fmt
  * \param dir
+ * \param flag
  *
  * This is only used by file storage based mailboxes.
  *
@@ -6522,11 +6531,12 @@
  * \param vmu
  * \param curdir
  * \param curmsg
- * \param vmfmts
+ * \param vm_fmts
  * \param context
  * \param record_gain
  * \param duration
  * \param vms
+ * \param flag 
  *
  * Presents a prompt for 1 to prepend the current message, 2 to forward the message without prepending, or * to return to the main menu.
  *
@@ -6705,6 +6715,7 @@
  * \param fmt
  * \param cidnum The Caller ID phone number value.
  * \param cidname The Caller ID name value.
+ * \param flag
  *
  * \return zero on success, -1 on error.
  */
@@ -6782,7 +6793,7 @@
 
 /*!
  * \brief Sends a voicemail message to a mailbox recipient.
- * \param ast_channel
+ * \param chan
  * \param context
  * \param vms
  * \param sender
@@ -6791,6 +6802,7 @@
  *             Will be 0 when called to forward an existing message (option 8)
  *             Will be 1 when called to leave a message (option 3->5)
  * \param record_gain 
+ * \param urgent
  *
  * Reads the destination mailbox(es) from keypad input for CID, or if use_directory feature is enabled, the Directory.
  * 
Index: apps/app_queue.c
===================================================================
--- apps/app_queue.c	(revision 261494)
+++ apps/app_queue.c	(working copy)
@@ -3197,6 +3197,7 @@
  * \param[in] prebusies number of busy members calculated prior to calling wait_for_answer
  * \param[in] caller_disconnect if the 'H' option is used when calling Queue(), this is used to detect if the caller pressed * to disconnect the call
  * \param[in] forwardsallowed used to detect if we should allow call forwarding, based on the 'i' option to Queue()
+ * \param[in] update_connectedline update the line information?
  *
  * \todo eventually all call forward logic should be intergerated into and replaced by ast_call_forward()
  */
Index: include/asterisk/rtp_engine.h
===================================================================
--- include/asterisk/rtp_engine.h	(revision 261494)
+++ include/asterisk/rtp_engine.h	(working copy)
@@ -595,6 +595,7 @@
  * \brief Send a frame out over RTP
  *
  * \param instance The RTP instance to send frame out on
+ * \param frame the frame to send out
  *
  * \retval 0 success
  * \retval -1 failure
@@ -864,7 +865,7 @@
  * \brief Copy payload information from one RTP instance to another
  *
  * \param src The source codecs structure
- * \param dst The destination codecs structure that the values from src will be copied to
+ * \param dest The destination codecs structure that the values from src will be copied to
  * \param instance Optionally the instance that the dst codecs structure belongs to
  *
  * Example usage:
@@ -926,7 +927,7 @@
 /*!
  * \brief Set payload type to a known MIME media type for a codec with a specific sample rate
  *
- * \param rtp RTP structure to modify
+ * \param codecs RTP structure to modify
  * \param instance Optionally the instance that the codecs structure belongs to
  * \param pt Payload type entry to modify
  * \param mimetype top-level MIME type of media stream (typically "audio", "video", "text", etc.)
@@ -1004,7 +1005,7 @@
  * \brief Retrieve all formats that were found
  *
  * \param codecs Codecs structure to look in
- * \param astFormats An integer to put the Asterisk formats in
+ * \param astformats An integer to put the Asterisk formats in
  * \param nonastformats An integer to put the non-Asterisk formats in
  *
  * Example usage:
Index: include/asterisk/xml.h
===================================================================
--- include/asterisk/xml.h	(revision 261494)
+++ include/asterisk/xml.h	(working copy)
@@ -90,7 +90,7 @@
 
 /*! \brief Open an XML document that resides in memory.
  * \param buffer The address where the document is stored
- * \size The number of bytes in the document
+ * \param size The number of bytes in the document
  * \retval NULL on error.
  * \retval The ast_xml_doc reference to the open document.
  */
@@ -119,7 +119,7 @@
 
 /*!
  * \brief Free an attribute returned by ast_xml_get_attribute()
- * \param data pointer to be freed.
+ * \param attribute pointer to be freed.
  */
 void ast_xml_free_attr(const char *attribute);
 
@@ -157,11 +157,11 @@
 
 /*!
  * \brief Find a node element by name.
- * \param node This is the node starting point.
+ * \param root_node This is the node starting point.
  * \param name Node name to find.
  * \param attrname attribute name to match (if NULL it won't be matched).
  * \param attrvalue attribute value to match (if NULL it won't be matched).
- * \retval NULL if not found
+ * \retval NULL if not found.
  * \retval The node on success.
  */
 struct ast_xml_node *ast_xml_find_element(struct ast_xml_node *root_node, const char *name, const char *attrname, const char *attrvalue);
Index: include/asterisk/channel.h
===================================================================
--- include/asterisk/channel.h	(revision 261494)
+++ include/asterisk/channel.h	(working copy)
@@ -1115,6 +1115,7 @@
  *
  * \param type type of channel to request
  * \param format requested channel format (codec)
+ * \param requestor channel asking for data
  * \param data data to pass to the channel requester
  * \param status status
  *
@@ -1133,6 +1134,7 @@
  *
  * \param type type of channel to request
  * \param format requested channel format
+ * \param requestor channel asking for data
  * \param data data to pass to the channel requester
  * \param timeout maximum amount of time to wait for an answer
  * \param reason why unsuccessful (if unsuccessful)
@@ -1150,6 +1152,7 @@
  * by the low level module and attempt to place a call on it
  * \param type type of channel to request
  * \param format requested channel format
+ * \param requestor channel requesting data
  * \param data data to pass to the channel requester
  * \param timeout maximum amount of time to wait for an answer
  * \param reason why unsuccessful (if unsuccessful)
@@ -1268,6 +1271,7 @@
  *
  * \param chan channel to set the field on
  * \param source a string describing the source of the hangup for this channel
+ * \param force
  *
  * \since 1.8
  *
@@ -1907,6 +1911,7 @@
  * ast_autoservice_stop and the autoservice thread. It is important
  * that chan is not locked prior to this call
  *
+ * \param chan
  * \retval 0 success
  * \retval -1 error, or the channel has been hungup
  */
@@ -1915,7 +1920,10 @@
 /*!
  * \brief Enable or disable timer ticks for a channel
  *
+ * \param c channel
  * \param rate number of timer ticks per second
+ * \param func callback function
+ * \param data
  *
  * \details
  * If timers are supported, force a scheduled expiration on the
@@ -2832,7 +2840,7 @@
  * name is used instead.
  *
  * \param chan The channel to retrieve the information from
- * \param device_name[out] The buffer to place the device's name into
+ * \param[out] device_name The buffer to place the device's name into
  * \param name_buffer_length The allocated space for the device_name
  * \return 0 always
  */
Index: include/asterisk/manager.h
===================================================================
--- include/asterisk/manager.h	(revision 261494)
+++ include/asterisk/manager.h	(working copy)
@@ -117,7 +117,7 @@
 void ast_manager_unregister_hook(struct manager_custom_hook *hook);
 
 /*! \brief Registered hooks can call this function to invoke actions and they will receive responses through registered callback
- * \param hookid the file identifier specified in manager_custom_hook struct when registering a hook
+ * \param hook the file identifier specified in manager_custom_hook struct when registering a hook
  * \param msg ami action mesage string e.g. "Action: SipPeers\r\n"
 
  * \retval 0 on Success
Index: include/asterisk/features.h
===================================================================
--- include/asterisk/features.h	(revision 261494)
+++ include/asterisk/features.h	(working copy)
@@ -120,26 +120,34 @@
 /*! \brief Pickup a call */
 int ast_pickup_call(struct ast_channel *chan);
 
-/*! \brief register new feature into feature_set 
-   \param feature an ast_call_feature object which contains a keysequence
-   and a callback function which is called when this keysequence is pressed
-   during a call. */
+/*! 
+ * \brief register new feature into feature_set 
+ * \param feature an ast_call_feature object which contains a keysequence
+ * and a callback function which is called when this keysequence is pressed
+ * during a call. 
+*/
 void ast_register_feature(struct ast_call_feature *feature);
 
-/*! \brief unregister feature from feature_set
-    \param feature the ast_call_feature object which was registered before*/
+/*! 
+ * \brief unregister feature from feature_set
+ * \param feature the ast_call_feature object which was registered before
+*/
 void ast_unregister_feature(struct ast_call_feature *feature);
 
-/*! \brief detect a feature before bridging 
-    \param chan
-    \param ast_flags ptr
-    \param char ptr of input code
-    \retval ast_call_feature ptr to be set if found 
-    \return result, was feature found or not */
+/*! 
+ * \brief detect a feature before bridging 
+ * \param chan
+ * \param features an ast_flags ptr
+ * \param code ptr of input code
+ * \param feature
+ * \retval ast_call_feature ptr to be set if found 
+*/
 int ast_feature_detect(struct ast_channel *chan, struct ast_flags *features, const char *code, struct ast_call_feature *feature);
 
-/*! \brief look for a call feature entry by its sname
-	\param name a string ptr, should match "automon", "blindxfer", "atxfer", etc. */
+/*! 
+ * \brief look for a call feature entry by its sname
+ * \param name a string ptr, should match "automon", "blindxfer", "atxfer", etc. 
+*/
 struct ast_call_feature *ast_find_call_feature(const char *name);
 
 void ast_rdlock_call_features(void);
@@ -148,8 +156,9 @@
 /*! \brief Reload call features from features.conf */
 int ast_features_reload(void);
 
-/* !\brief parse L option and read associated channel variables to set warning, warning frequency, and timelimit
-	\note caller must be aware of freeing memory for warning_sound, end_sound, and start_sound
+/*!
+ * \brief parse L option and read associated channel variables to set warning, warning frequency, and timelimit
+ * \note caller must be aware of freeing memory for warning_sound, end_sound, and start_sound
 */
 int ast_bridge_timelimit(struct ast_channel *chan, struct ast_bridge_config *config, char *parse, struct timeval *calldurationlimit);
 
Index: include/asterisk/http.h
===================================================================
--- include/asterisk/http.h	(revision 261494)
+++ include/asterisk/http.h	(working copy)
@@ -171,8 +171,8 @@
 
 /*!
  * \brief Return the current prefix
- * \param buf[out] destination buffer for previous
- * \param len[in] length of prefix to copy
+ * \param[out] buf destination buffer for previous
+ * \param[in] len length of prefix to copy
  * \since 1.6.1
  */
 void ast_http_prefix(char *buf, int len);
Index: include/asterisk/app.h
===================================================================
--- include/asterisk/app.h	(revision 261494)
+++ include/asterisk/app.h	(working copy)
@@ -136,6 +136,7 @@
 
 /*!
  * \brief Set voicemail function callbacks
+ * \param[in] has_voicemail_func set function pointer
  * \param[in] inboxcount2_func set function pointer
  * \param[in] sayname_func set function pointer
  * \param[in] inboxcount_func set function pointer
Index: include/asterisk/smdi.h
===================================================================
--- include/asterisk/smdi.h	(revision 261494)
+++ include/asterisk/smdi.h	(working copy)
@@ -122,7 +122,7 @@
 /*!
  * \brief Put an SMDI message back in the front of the queue.
  * \param iface a pointer to the interface to use.
- * \param md_msg a pointer to the message to use.
+ * \param msg a pointer to the message to use.
  *
  * This function puts a message back in the front of the specified queue.  It
  * should be used if a message was popped but is not going to be processed for
@@ -169,7 +169,7 @@
 /*!
  * \brief Put an SMDI message back in the front of the queue.
  * \param iface a pointer to the interface to use.
- * \param mwi_msg a pointer to the message to use.
+ * \param msg a pointer to the message to use.
  *
  * This function puts a message back in the front of the specified queue.  It
  * should be used if a message was popped but is not going to be processed for
Index: include/asterisk/data.h
===================================================================
--- include/asterisk/data.h	(revision 261494)
+++ include/asterisk/data.h	(working copy)
@@ -601,7 +601,7 @@
  * \brief Add a string node type.
  * \param[in] root The root of the ast_data to insert into.
  * \param[in] childname The name of the child element to be added.
- * \param[in] value The value for the new node.
+ * \param[in] string The value for the new node.
  * \retval NULL on error (memory exhaustion only).
  * \retval non-NULL a newly allocated node.
  */
@@ -612,7 +612,7 @@
  * \brief Add a boolean node type.
  * \param[in] root The root of the ast_data to insert into.
  * \param[in] childname The name of the child element to be added.
- * \param[in] value The value for the new node.
+ * \param[in] boolean The value for the new node.
  * \retval NULL on error (memory exhaustion only).
  * \retval non-NULL a newly allocated node.
  */
Index: include/asterisk/event.h
===================================================================
--- include/asterisk/event.h	(revision 261494)
+++ include/asterisk/event.h	(working copy)
@@ -192,7 +192,8 @@
  *
  * \param sub the dynamic subscription allocated with ast_event_subscribe_new()
  * \param ie_type the information element type for the parameter
- * \param raw the data that must be present in the event to match this subscription
+ * \param data the data that must be present in the event to match this subscription
+ * \param raw_datalen length of data
  *
  * \retval 0 success
  * \retval non-zero failure
@@ -480,7 +481,7 @@
  *
  * \param event the event that the IE will be appended to
  * \param ie_type the type of IE to append
- * \param flags the flags that are the payload of the IE
+ * \param bitflags the flags that are the payload of the IE
  *
  * \retval 0 success
  * \retval -1 failure
Index: include/asterisk/astmm.h
===================================================================
--- include/asterisk/astmm.h	(revision 261494)
+++ include/asterisk/astmm.h	(working copy)
@@ -19,7 +19,7 @@
 /*! \file
  * \brief Asterisk memory usage debugging
  * This file provides headers for MALLOC_DEBUG, a define used for tracking down
- * memory leaks.  It should never be #included directly; always use the
+ * memory leaks.  It should never be \#included directly; always use the
  * MALLOC_DEBUG definition in menuselect to activate those functions.
  */
 
Index: include/asterisk/timing.h
===================================================================
--- include/asterisk/timing.h	(revision 261494)
+++ include/asterisk/timing.h	(working copy)
@@ -84,7 +84,7 @@
 /*!
  * \brief Register a set of timing functions.
  *
- * \param funcs An instance of the \c ast_timing_interfaces structure with pointers
+ * \param i An instance of the \c ast_timing_interfaces structure with pointers
  *        to the functions provided by the timing implementation.
  *
  * \retval NULL failure 
Index: include/asterisk/ccss.h
===================================================================
--- include/asterisk/ccss.h	(revision 261494)
+++ include/asterisk/ccss.h	(working copy)
@@ -1321,6 +1321,7 @@
  * up the ladder correctly.
  *
  * \param core_id The core ID of the corresponding CC transaction
+ * \param debug
  * \retval 0 Request successfully queued
  * \retval -1 Request could not be queued
  */
@@ -1377,7 +1378,7 @@
  * sure that you have no potential lock order issues here.
  *
  * \param chan The channel to check
- * \param core_id[out] If this is a valid CC recall, the core_id of the failed call
+ * \param[out] core_id If this is a valid CC recall, the core_id of the failed call
  * will be placed in this output parameter
  * \param monitor_type Clarify which type of monitor type we are looking for if this
  * is happening on a called channel. For incoming channels, this parameter is not used.
@@ -1508,7 +1509,8 @@
  * ready, and then based on set flags, creates the proper frame type. For chan_dahdi, we
  * provide this function. It provides us the data we need, and we'll make its frame for it.
  *
- * \param chan A channel involved in the call. What we want is on a datastore on both incoming and outgoing so either may be provided
+ * \param chan A channel involved in the call. What we want is on a datastore on both incoming 
+ * and outgoing so either may be provided
  * \param cc_params The CC configuration parameters for the outbound target
  * \param monitor_type The type of monitor to use when CC is requested
  * \param device_name The name of the outbound target device.
@@ -1518,8 +1520,8 @@
  * data has been allocated, then this parameter should contain a pointer to that data. If using a generic
  * monitor, this parameter should remain NULL. Note that if this function should fail at some point,
  * it is the responsibility of the caller to free the private data upon return.
- * \param[out] frame. The frame we will be returning to the caller. It is vital that ast_frame_free be called on this frame since the
- * payload will be allocated on the heap.
+ * \param[out] frame The frame we will be returning to the caller. It is vital that ast_frame_free be 
+ * called on this frame since the payload will be allocated on the heap.
  * \retval -1 Failure. At some point there was a failure. Do not attempt to use the frame in this case.
  * \retval 0 Success
  */
@@ -1561,6 +1563,7 @@
  * See the explanation in ast_channel_tech::cc_callback for more
  * details.
  *
+ * \param inbound
  * \param tech Channel technology to use
  * \param dest Channel/group/peer or whatever the specific technology uses
  * \param callback Function to call when a target is reached
Index: include/asterisk/threadstorage.h
===================================================================
--- include/asterisk/threadstorage.h	(revision 261494)
+++ include/asterisk/threadstorage.h	(working copy)
@@ -88,11 +88,11 @@
 /*!
  * \brief Define a thread storage variable, with custom initialization and cleanup
  *
- * \param name The name of the thread storage object
- * \param init This is a custom function that will be called after each thread specific
+ * \param a The name of the thread storage object
+ * \param b This is a custom function that will be called after each thread specific
  *           object is allocated, with the allocated block of memory passed
  *           as the argument.
- * \param cleanup This is a custom function that will be called instead of ast_free
+ * \param c This is a custom function that will be called instead of ast_free
  *              when the thread goes away.  Note that if this is used, it *MUST*
  *              call free on the allocated memory.
  *
Index: include/asterisk/astobj2.h
===================================================================
--- include/asterisk/astobj2.h	(revision 261494)
+++ include/asterisk/astobj2.h	(working copy)
@@ -431,6 +431,7 @@
  *
  * \param o A pointer to the object
  * \param delta Value to add to the reference counter.
+ * \param tag used for debugging
  * \return The value of the reference counter before the operation.
  *
  * Increase/decrease the reference counter according
@@ -695,13 +696,15 @@
  * We allocate space for a struct astobj_container, struct container
  * and the buckets[] array.
  *
- * \param n_buckets Number of buckets for hash
- * \param hash_fn Pointer to a function computing a hash value.
- * \param cmp_fn Pointer to a function comparating key-value
+ * \param arg1 Number of buckets for hash
+ * \param arg2 Pointer to a function computing a hash value.
+ * \param arg3 Pointer to a function comparating key-value
  * 			with a string. (can be NULL)
+ * \param arg4
+ *
  * \return A pointer to a struct container.
  *
- * destructor is set implicitly.
+ * \note Destructor is set implicitly.
  */
 
 #if defined(REF_DEBUG)
@@ -746,10 +749,11 @@
 /*!
  * \brief Add an object to a container.
  *
- * \param c the container to operate on.
- * \param newobj the object to be added.
+ * \param arg1 the container to operate on.
+ * \param arg2 the object to be added.
+ * \param arg3 used for debuging.
  *
- * \retval NULL on errors
+ * \retval NULL on errors.
  * \retval newobj on success.
  *
  * This function inserts an object in a container according its key.
@@ -777,8 +781,9 @@
 /*!
  * \brief Remove an object from a container
  *
- * \param c the container
- * \param obj the object to unlink
+ * \param arg1 the container
+ * \param arg2 the object to unlink
+ * \param arg3 tag for debugging
  *
  * \retval NULL, always
  *
@@ -837,6 +842,7 @@
           flags is the same as flags passed into ao2_callback (flags are
            also used by ao2_callback).
  * \param arg passed to the callback.
+ * \param tag used for debuging.
  * \return when OBJ_MULTIPLE is not included in the flags parameter,
  *         the return value will be either the object found or NULL if no
  *         no matching object was found. if OBJ_MULTIPLE is included,
Index: include/asterisk/calendar.h
===================================================================
--- include/asterisk/calendar.h	(revision 261494)
+++ include/asterisk/calendar.h	(working copy)
@@ -146,7 +146,7 @@
  * \param tech calendar technology to unregister
  *
  * \retval 0 success
- * \retva -1 failure
+ * \retval -1 failure
  */
 void ast_calendar_unregister(struct ast_calendar_tech *tech);
 
Index: include/asterisk/logger.h
===================================================================
--- include/asterisk/logger.h	(revision 261494)
+++ include/asterisk/logger.h	(working copy)
@@ -182,14 +182,14 @@
 
 /*!
  * \brief Get the debug level for a module
- * \param file the filename
+ * \param module the name of module
  * \return the debug level
  */
 unsigned int ast_debug_get_by_module(const char *module);
 
 /*!
  * \brief Get the verbose level for a module
- * \param file the filename
+ * \param module the name of module
  * \return the verbose level
  */
 unsigned int ast_verbose_get_by_module(const char *module);
Index: include/asterisk/pbx.h
===================================================================
--- include/asterisk/pbx.h	(revision 261494)
+++ include/asterisk/pbx.h	(working copy)
@@ -380,7 +380,7 @@
 /*!
  * \brief Map devstate to an extension state.
  *
- * \param[in] device state
+ * \param[in] devstate device state
  *
  * \return the extension state mapping.
  */
@@ -725,8 +725,6 @@
  * \param context context to remove extension from
  * \param extension which extension to remove
  * \param priority priority of extension to remove (0 to remove all)
- * \param callerid NULL to remove all; non-NULL to match a single record per priority
- * \param matchcid non-zero to match callerid element (if non-NULL); 0 to match default case
  * \param registrar registrar of the extension
  *
  * This function removes an extension from a given context.
Index: include/asterisk/dnsmgr.h
===================================================================
--- include/asterisk/dnsmgr.h	(revision 261494)
+++ include/asterisk/dnsmgr.h	(working copy)
@@ -42,7 +42,7 @@
  *
  * \param name the hostname
  * \param result where the DNS manager should store the IP address as it refreshes it.
- *      it.
+ * \param service
  *
  * This function allocates a new DNS manager entry object, and fills it with the
  * provided hostname and IP address.  This function does not force an initial lookup
@@ -69,6 +69,7 @@
  * \param name the hostname
  * \param result where to store the IP address as the DNS manager refreshes it
  * \param dnsmgr Where to store the allocate DNS manager entry
+ * \param service
  *
  * This function allocates a new DNS manager entry object, and fills it with
  * the provided hostname and IP address.  This function _does_ force an initial
Index: include/asterisk/callerid.h
===================================================================
--- include/asterisk/callerid.h	(revision 261494)
+++ include/asterisk/callerid.h	(working copy)
@@ -181,9 +181,14 @@
 
 /*!
  * \brief Generate message waiting indicator
+ * \param buf
  * \param active The message indicator state
  *  -- either 0 no messages in mailbox or 1 messages in mailbox
  * \param type Format of message (any of CID_MWI_TYPE_*)
+ * \param codec
+ * \param name
+ * \param number
+ * \param flags
  * \see callerid_generate() for more info as it uses the same encoding
  * \version 1.6.1 changed mdmf parameter to type, added name, number and flags for caller id message generation
  */
Index: include/asterisk/doxyref.h
===================================================================
--- include/asterisk/doxyref.h	(revision 261494)
+++ include/asterisk/doxyref.h	(working copy)
@@ -345,7 +345,7 @@
 /*! 
  * \page Config_fea Call features configuration
  * \par See also
- * \arg \ref res_features.c : Call feature implementation
+ * \arg \ref features.c : Call feature implementation
  * \section featconf features.conf
  * \verbinclude features.conf.sample
  */
Index: include/asterisk/bridging_technology.h
===================================================================
--- include/asterisk/bridging_technology.h	(revision 261494)
+++ include/asterisk/bridging_technology.h	(working copy)
@@ -83,7 +83,7 @@
 /*! \brief Register a bridge technology for use
  *
  * \param technology The bridge technology to register
- * \param module The module that is registering the bridge technology
+ * \param mod The module that is registering the bridge technology
  *
  * \retval 0 on success
  * \retval -1 on failure
Index: main/ast_expr2f.c
===================================================================
--- main/ast_expr2f.c	(revision 261494)
+++ main/ast_expr2f.c	(working copy)
@@ -1966,8 +1966,8 @@
 
 /** Setup the input buffer state to scan the given bytes. The next call to ast_yylex() will
  * scan from a @e copy of @a bytes.
- * @param bytes the byte buffer to scan
- * @param len the number of bytes in the buffer pointed to by @a bytes.
+ * @param yybytes the byte buffer to scan
+ * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
  * @param yyscanner The scanner object.
  * @return the newly allocated buffer state object.
  */
@@ -2128,7 +2128,7 @@
 }
 
 /** Set the current column.
- * @param line_number
+ * @param column_no 
  * @param yyscanner The scanner object.
  */
 void ast_yyset_column (int  column_no , yyscan_t yyscanner)
Index: main/features.c
===================================================================
--- main/features.c	(revision 261494)
+++ main/features.c	(working copy)
@@ -2415,7 +2415,7 @@
 
 /*!
  * \brief Helper function for feature_interpret and ast_feature_detect
- * \param chan,peer,config,code,sense,dynamic_features char buf,feature flags,operation,feature
+ * \param chan,peer,config,code,sense,dynamic_features_buf,features,operation,feature
  *
  * Lock features list, browse for code, unlock list
  * If a feature is found and the operation variable is set, that feature's
@@ -2605,7 +2605,7 @@
 
 /*! 
  * \brief Get feature and dial
- * \param caller,transferee,type,format,data,timeout,outstate,cid_num,cid_name,igncallerstate
+ * \param caller,transferee,type,format,data,timeout,outstate,cid_num,cid_name,igncallerstate,language
  *
  * Request channel, set channel variables, initiate call,check if they want to disconnect
  * go into loop, check if timeout has elapsed, check if person to be transfered hung up,
Index: main/ccss.c
===================================================================
--- main/ccss.c	(revision 261494)
+++ main/ccss.c	(working copy)
@@ -1453,7 +1453,7 @@
 	 * to find the dialstring that corresponds to that device, and we use the
 	 * stored device name as a way to find it.
 	 *
-	 * Note that there is one particular case where the device name stored here
+	 * \note There is one particular case where the device name stored here
 	 * will be empty. This is the case where we fail to request a channel, but we
 	 * still can make use of generic call completion. In such a case, since we never
 	 * were able to request the channel, we can't find what its device name is. In
Index: main/pbx.c
===================================================================
--- main/pbx.c	(revision 261494)
+++ main/pbx.c	(working copy)
@@ -4560,6 +4560,7 @@
 
 /*!
  * \brief collect digits from the channel into the buffer.
+ * \param c, buf, buflen, pos
  * \param waittime is in milliseconds
  * \retval 0 on timeout or done.
  * \retval -1 on error.
Index: main/audiohook.c
===================================================================
--- main/audiohook.c	(revision 261494)
+++ main/audiohook.c	(working copy)
@@ -371,8 +371,8 @@
 }
 
 /*! \brief Update audiohook's status
- * \param audiohook status enum
  * \param audiohook Audiohook structure
+ * \param status Audiohook status enum
  *
  * \note once status is updated to DONE, this function can not be used to set the
  * status back to any other setting.  Setting DONE effectively locks the status as such.
Index: res/res_config_sqlite.c
===================================================================
--- res/res_config_sqlite.c	(revision 261494)
+++ res/res_config_sqlite.c	(working copy)
@@ -272,6 +272,7 @@
  * \param cfg the struct ast_config object to use when storing variables
  * \param flags Optional flags.  Not used.
  * \param suggested_incl suggest include.
+ * \param who_asked
  * \retval cfg object
  * \retval NULL if an error occurred
  * \see add_cfg_entry()
@@ -298,6 +299,7 @@
  * \param ap the va_list object to parse
  * \param params_ptr where the address of the params array is stored
  * \param vals_ptr where the address of the vals array is stored
+ * \param warn
  * \retval the number of elements in the arrays (which have the same size).
  * \retval 0 if an error occurred.
  */
Index: res/res_jabber.c
===================================================================
--- res/res_jabber.c	(revision 261494)
+++ res/res_jabber.c	(working copy)
@@ -2484,6 +2484,7 @@
 /*!
 * \brief sends messages.
 * \param client the configured XMPP client we use to connect to a XMPP server
+* \param groupchat 
 * \param nick the nickname we use in chatrooms
 * \param address
 * \param message
